﻿// Brandon Haynes - http://brandonhaynes.org
// Copyright (c) 2008
// by Brandon Haynes

// Please refer to the project license, located at http://www.codeplex.com/DNNLocalization/license

// The above copyright notice and this permission notice shall be included in all copies or substantial portions 
// of the Software.

//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, 
//INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
//DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
//SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
//SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
//WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
//USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 

using System.Globalization;
using BrandonHaynes.DotNetNukeResXBuildProvider;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace TestHarness
	{
	[TestClass]
	public class ResourcePathMetaDataTests
		{
		public TestContext TestContext { get; set; }

		#region Additional test attributes
		//
		// You can use the following additional attributes as you write your tests:
		//
		// Use ClassInitialize to run code before running the first test in the class
		// [ClassInitialize()]
		// public static void MyClassInitialize(TestContext testContext) { }
		//
		// Use ClassCleanup to run code after all tests in a class have run
		// [ClassCleanup()]
		// public static void MyClassCleanup() { }
		//
		// Use TestInitialize to run code before running each test 
		// [TestInitialize()]
		// public void MyTestInitialize() { }
		//
		// Use TestCleanup to run code after each test has run
		// [TestCleanup()]
		// public void MyTestCleanup() { }
		//
		#endregion

		[TestMethod]
		public void RegEx_GlobalInvariant()
			{
			var resourceData = new ResourcePathMetadata("GlobalResources.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "resources.globalresources.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources");
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "GlobalResources.resx");
			}

		[TestMethod]
		public void RegEx_PathGlobalLocalizedPortal()
			{
			var resourceData = new ResourcePathMetadata("/Test/App_GlobalResources/GlobalResources.de-DE.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("de-DE"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.portal0.globalresources.de-de.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "/Test/App_GlobalResources/GlobalResources.de-DE.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalUnlocalizedPortal()
			{
			var resourceData = new ResourcePathMetadata("GlobalResources.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "resources.portal0.globalresources.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "GlobalResources.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalized()
			{
			var resourceData = new ResourcePathMetadata("GlobalResources.en-US.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.globalresources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources");
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "GlobalResources.en-US.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedPortal()
			{
			var resourceData = new ResourcePathMetadata("GlobalResources.en-US.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.portal0.globalresources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "GlobalResources.en-US.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalNamespace()
			{
			var resourceData = new ResourcePathMetadata("Namespace.GlobalResources.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace.globalresources.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace");
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace.GlobalResources.resx");
			}

		[TestMethod]
		public void RegEx_GlobalPortalNamespace()
			{
			var resourceData = new ResourcePathMetadata("Namespace.GlobalResources.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace.portal0.globalresources.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace.GlobalResources.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedNamespace()
			{
			var resourceData = new ResourcePathMetadata("Namespace.GlobalResources.en-US.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace.globalresources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace");
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace.GlobalResources.en-US.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedPortalNamespace()
			{
			var resourceData = new ResourcePathMetadata("Namespace.GlobalResources.en-US.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace.portal0.globalresources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace.GlobalResources.en-US.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalNamespaces()
			{
			var resourceData = new ResourcePathMetadata("Namespace1.Namespace2.GlobalResources.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace1.namespace2.globalresources.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace1.Namespace2");
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace1.Namespace2.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace1.Namespace2.GlobalResources.resx");
			}

		[TestMethod]
		public void RegEx_GlobalPortalNamespaces()
			{
			var resourceData = new ResourcePathMetadata("Namespace1.Namespace2.GlobalResources.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace1.namespace2.portal0.globalresources.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace1.Namespace2.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace1.Namespace2.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace1.Namespace2.GlobalResources.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedNamespaces()
			{
			var resourceData = new ResourcePathMetadata("Namespace1.Namespace2.GlobalResources.en-US.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace1.namespace2.globalresources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace1.Namespace2");
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace1.Namespace2.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace1.Namespace2.GlobalResources.en-US.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedPortalNamespaces()
			{
			var resourceData = new ResourcePathMetadata("Namespace1.Namespace2.GlobalResources.en-US.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.namespace1.namespace2.portal0.globalresources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Namespace1.Namespace2.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Namespace1.Namespace2.Portal0.GlobalResources");
			Assert.AreEqual(resourceData.TypeName, "GlobalResources");
			Assert.AreEqual(resourceData.VirtualPath, "Namespace1.Namespace2.GlobalResources.en-US.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_Local()
			{
			var resourceData = new ResourcePathMetadata("IconBar.ascx.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.InvariantCulture);
			Assert.AreEqual(resourceData.EmbeddedName, "iconbar.ascx.resources");
			Assert.AreEqual(resourceData.IsLocal, true);
			Assert.AreEqual(resourceData.Namespace, string.Empty);
			Assert.AreEqual(resourceData.PortalId, null);
			Assert.AreEqual(resourceData.QualifiedTypeName, "IconBar.ascx");
			Assert.AreEqual(resourceData.TypeName, "IconBar.ascx");
			Assert.AreEqual(resourceData.VirtualPath, "IconBar.ascx.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedPortalNamespacesWithSpaces()
			{
			var resourceData = new ResourcePathMetadata("Name space1.Name space2.Global Resources.en-US.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.name_space1.name_space2.portal0.global_resources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Name_space1.Name_space2.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Name_space1.Name_space2.Portal0.Global_Resources");
			Assert.AreEqual(resourceData.TypeName, "Global_Resources");
			Assert.AreEqual(resourceData.VirtualPath, "Name space1.Name space2.Global Resources.en-US.Portal-0.resx");
			}

		[TestMethod]
		public void RegEx_GlobalLocalizedPortalNamespacesOtherCharacters()
			{
			var resourceData = new ResourcePathMetadata("Name$space1.Name#space2.Global!Resources.en-US.Portal-0.resx");
			Assert.AreEqual(resourceData.Culture, CultureInfo.GetCultureInfo("en-US"));
			Assert.AreEqual(resourceData.EmbeddedName, "resources.name_space1.name_space2.portal0.global_resources.en-us.resources");
			Assert.AreEqual(resourceData.IsLocal, false);
			Assert.AreEqual(resourceData.Namespace, "Resources.Name_space1.Name_space2.Portal0");
			Assert.AreEqual(resourceData.PortalId, 0);
			Assert.AreEqual(resourceData.QualifiedTypeName, "Resources.Name_space1.Name_space2.Portal0.Global_Resources");
			Assert.AreEqual(resourceData.TypeName, "Global_Resources");
			Assert.AreEqual(resourceData.VirtualPath, "Name$space1.Name#space2.Global!Resources.en-US.Portal-0.resx");
			}
		}
	}
